package com.dacarnix.ringtone_helper;

import android.content.Context;
import android.media.AudioManager;
import android.app.Activity;
import android.content.Intent;
import android.provider.Settings;
import android.net.Uri;
import android.media.MediaScannerConnection;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** RingtoneHelperPlugin */
public class RingtoneHelperPlugin implements MethodCallHandler {
  private final Activity activity;
  private final Registrar registrar;

	private RingtoneHelperPlugin(Registrar registrar, Activity activity)
	{
    this.registrar = registrar;
		this.activity = activity;
	}

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "ringtone_helper");
    channel.setMethodCallHandler(new RingtoneHelperPlugin(registrar, registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
		if (call.method.equals("openSoundSettings")) {
			try {
				final Intent intent = new Intent(Settings.ACTION_SOUND_SETTINGS);
				activity.startActivity(intent);
				result.success(true);
			} catch (Exception e) {
				result.success(false);
			}
    }
    else if (call.method.equals("scanFile")) {
      try {
        String file = call.argument("filePath");

        if (file == null) {
          result.success(false);
          return;
        }

        MediaScannerConnection.scanFile(
          registrar.context().getApplicationContext(),
          new String[] { file },
          null,
          null);

        result.success(true);
			} catch (Exception e) {
				result.success(false);
			}
    }
    else if (call.method.equals("getAlarmFolderName")) {
      result.success(android.os.Environment.DIRECTORY_ALARMS);
    } 
		else if (call.method.equals("getRingtoneFolderName")) {
      result.success(android.os.Environment.DIRECTORY_RINGTONES);
    } 
    else if (call.method.equals("getNotificationFolderName")) {
      result.success(android.os.Environment.DIRECTORY_NOTIFICATIONS);
    } else {
      result.notImplemented();
    }
  }
}
